ChatForwardingExecutor class

Forwards chat protocol messages to another workflow executor.

Inheritance
Available extensions

Constructors

ChatForwardingExecutor(String id, String targetExecutorId)
Creates a forwarding executor that sends chat messages to targetExecutorId.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Gets the executor identifier.
finalinherited
options ExecutorOptions
Gets options describing runtime behavior for this executor.
finalinherited
protocol ProtocolDescriptor
Gets the executor protocol descriptor.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetExecutorId String
Gets the target executor identifier.
final

Methods

bindConfiguredExecutor([ExecutorConfig config = const ExecutorConfig()]) ConfiguredExecutorBinding

Available on Executor, provided by the ExecutorInstanceBindingExtensions extension

Creates a configured shared instance binding for this executor.
bindExecutor() ExecutorInstanceBinding

Available on Executor, provided by the ExecutorInstanceBindingExtensions extension

Creates a shared instance binding for this executor.
canAccept(Type messageType) bool
Gets whether this executor can accept a message of messageType.
inherited
configureProtocol(ProtocolBuilder builder) → void
Configures the message protocol for this executor.
override
describeProtocol() ProtocolDescriptor
Builds the executor protocol descriptor.
inherited
handle(Object? message, WorkflowContext context, {CancellationToken? cancellationToken}) Future<void>
Handles an inbound message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited