CheckpointInfoConverter class final

Provides serialization and dictionary-key support for CheckpointInfo values.

The key format is the escaped CheckpointInfo.checkpointId.

Inheritance

Constructors

CheckpointInfoConverter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Object? json) CheckpointInfo?
Deserializes json into a T, or null if conversion fails.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String key) CheckpointInfo
Parses a JSON map key back into T.
override
stringify(CheckpointInfo value) String
Converts value to a string suitable for use as a JSON map key.
override
toJson(CheckpointInfo value) Object?
Serializes value to a JSON-compatible object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited