DelayedDeserialization class abstract interface

Supports lazy deserialization of a value when the target type is not known until retrieval time.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize<T>() → T
Deserializes the stored value as T.
deserializeAs(Type targetType) Object?
Deserializes the stored value as targetType, or returns null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited