DeliveryMapping class final

Maps one or more MessageEnvelopes to one or more executor targets.

Constructors

DeliveryMapping(Iterable<MessageEnvelope> _envelopes, Iterable<Executor> _targets)
Creates a DeliveryMapping from envelopes to targets.
DeliveryMapping.single(MessageEnvelope envelope, Executor target)
Convenience constructor for a single envelope and single target.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapInto(Map<String, List<MessageEnvelope>> queue) → void
Enqueues all envelope/target combinations into queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited