EdgeMap class

Indexes workflow edges by their source executor identifiers.

Constructors

EdgeMap(Iterable<Edge> edges)
Creates an edge map.

Properties

edges Iterable<Edge>
Gets all edges in insertion order.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEdgesFrom(String sourceExecutorId) Iterable<Edge>
Gets edges whose source includes sourceExecutorId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited