EdgeRunner class abstract

Base class for all workflow edge runners.

Concrete subclasses implement chaseEdge to decide which executor(s) should receive a given MessageEnvelope.

Implementers

Constructors

EdgeRunner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chaseEdge(MessageEnvelope envelope, {StepTracer? stepTracer}) DeliveryMapping?
Attempts to route envelope and returns a DeliveryMapping when the edge accepts the message, or null when it does not apply.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited