EvalCheckResult class

Result of a single check on a single evaluation item.

Passed Whether the check passed.

Reason Human-readable explanation.

CheckName Name of the check that produced this result.

Constructors

EvalCheckResult(bool passed, String reason, String checkName)
Result of a single check on a single evaluation item.
const

Properties

checkName String
Name of the check that produced this result.
final
hashCode int
The hash code for this object.
no setteroverride
passed bool
Whether the check passed.
final
reason String
Human-readable explanation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override