Event name constants used in workflow telemetry.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- buildCompleted → const String
- buildError → const String
- buildStarted → const String
- buildValidationCompleted → const String
- sessionCompleted → const String
- sessionError → const String
- sessionStarted → const String
- workflowCompleted → const String
- workflowError → const String
- workflowStarted → const String