ExecutorFailedEvent class

Event emitted when an executor fails.

Inheritance

Constructors

ExecutorFailedEvent({required String executorId, required Object error})
Creates an executor-failed event.
const

Properties

data Object?
Gets event payload data, if any.
finalinherited
error Object
Gets the executor error.
final
executorId String
Gets the executor identifier.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asValue<T>() → T
Gets the event payload as T.
inherited
isType(Type type) bool
Gets whether the event payload has exactly runtime type type.
inherited
isValue<T>() bool
Gets whether the event payload is a T.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited