stringify method
Converts value to a string suitable for use as a JSON map key.
Implementation
@override
String stringify(ExecutorIdentity value) =>
value == ExecutorIdentity.none ? '' : '@${value.id}';
Converts value to a string suitable for use as a JSON map key.
@override
String stringify(ExecutorIdentity value) =>
value == ExecutorIdentity.none ? '' : '@${value.id}';