OpenTelemetryAgentTags class

OpenTelemetry attribute name constants for the agent identity dimension.

Constructors

OpenTelemetryAgentTags()
const

Properties

description String
Attribute key for the agent description.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Attribute key for the agent identifier.
no setter
name String
Attribute key for the agent display name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited