OutputMessagesExecutor class

Batches received chat messages and publishes them as the final result.

Inheritance
Implemented types

Constructors

OutputMessagesExecutor()
Creates an OutputMessagesExecutor.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Gets the executor identifier.
finalinherited
options ExecutorOptions
Gets options describing runtime behavior for this executor.
finalinherited
protocol ProtocolDescriptor
Gets the executor protocol descriptor.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canAccept(Type messageType) bool
Gets whether this executor can accept a message of messageType.
inherited
configureProtocol(ProtocolBuilder builder) → void
Configures the message protocol for this executor.
override
describeProtocol() ProtocolDescriptor
Builds the executor protocol descriptor.
inherited
handle(Object? message, WorkflowContext context, {CancellationToken? cancellationToken}) Future<List<ChatMessage>>
Handles an inbound message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() Future<bool>
Attempts to reset the executor.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

executorId → const String
Gets the executor identifier.