ShellCommandRejectedException class

Thrown by a ShellExecutor when a ShellPolicy denies a command.

Implemented types

Constructors

ShellCommandRejectedException(String command, {String? reason})
Creates a ShellCommandRejectedException for the given command.
const

Properties

command String
The command that was rejected.
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
The policy reason for rejection, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited