SummarizationCompactionStrategy class

A compaction strategy that uses an LLM to summarize older portions of the conversation.

Inheritance
Available extensions

Constructors

SummarizationCompactionStrategy(ChatClient chatClient, CompactionTrigger trigger, {int? minimumPreservedGroups, String? summarizationPrompt, CompactionTrigger? target})

Properties

chatClient → ChatClient
final
hashCode int
The hash code for this object.
no setterinherited
minimumPreservedGroups int
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summarizationPrompt String
latefinal
target CompactionTrigger
finalinherited
trigger CompactionTrigger
finalinherited

Methods

asChatReducer() → ChatReducer

Available on CompactionStrategy, provided by the ChatStrategyExtensions extension

compact(CompactionMessageIndex index, {Logger? logger, CancellationToken? cancellationToken}) Future<bool>
inherited
compactCore(CompactionMessageIndex index, Logger logger, CancellationToken cancellationToken) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited