stateKeys property

  1. @override
List<String> get stateKeys
override

The keys used to store provider state in the StateBag.

Defaults to a single key equal to the runtime type name.

Implementation

@override
List<String> get stateKeys {
  return _stateKeys ??= [_sessionState.stateKey];
}