TypeId class

Identifies a serialized Dart type in checkpoint wire data.

Constructors

TypeId(String value)
Creates a type id.
const
TypeId.fromType(Type type)
Creates a type id from type.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Gets the type id string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override