Utf8JsonReader class

Mirrors C# System.Text.Json.Utf8JsonReader.

Constructors

Utf8JsonReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
position int
The current byte position within the JSON data.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getString() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited