WorkflowEvent class

Base type for workflow events.

Implementers

Constructors

WorkflowEvent({Object? data})
Creates a workflow event.
const

Properties

data Object?
Gets event payload data, if any.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asValue<T>() → T
Gets the event payload as T.
isType(Type type) bool
Gets whether the event payload has exactly runtime type type.
isValue<T>() bool
Gets whether the event payload is a T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited