AIContext class
Additional context that AIContextProvider instances supply to enhance AI model interactions during agent invocations.
This context is merged with the agent's base configuration before being passed to the underlying AI model. Context information is transient by default and applies only to the current invocation; however, messages added through messages may be permanently incorporated into conversation history.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instructions ↔ String?
-
Additional instructions to provide to the AI model for this invocation.
getter/setter pair
-
messages
↔ Iterable<
ChatMessage> ? -
Messages to include in the current invocation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
↔ Iterable<
AITool> ? -
Tools or functions to make available to the AI model for this invocation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited