AgentRequestMessageSourceType class
The source of an agent request message.
Input messages for a specific agent run can originate from various sources, such as user input, AI context providers, or chat history.
Constructors
- AgentRequestMessageSourceType(String value)
-
Creates an AgentRequestMessageSourceType with the given
value.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- aiContextProvider → const AgentRequestMessageSourceType
- The message was produced by an AI context provider.
- chatHistory → const AgentRequestMessageSourceType
- The message came from chat history.
- externalValue → const AgentRequestMessageSourceType
- The message came from outside the agent pipeline (e.g., user input).