AlwaysApproveToolApprovalResponseContent class
Wraps a ToolApprovalResponseContent with additional "always approve"
settings, enabling the ToolApprovalAgent middleware to record standing
approval rules so that future matching tool calls are auto-approved without
user interaction.
Constructors
- AlwaysApproveToolApprovalResponseContent(ToolApprovalResponseContent? innerResponse, bool alwaysApproveTool, bool alwaysApproveToolWithArguments)
-
Creates an AlwaysApproveToolApprovalResponseContent wrapping
innerResponse.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- alwaysApproveTool → bool
-
Gets a value indicating whether all future calls to the same tool should
be auto-approved regardless of the arguments provided.
final
- alwaysApproveToolWithArguments → bool
-
Gets a value indicating whether all future calls to the same tool with the
exact same arguments should be auto-approved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerResponse → ToolApprovalResponseContent
-
Gets the underlying
ToolApprovalResponseContentthat will be forwarded to the inner agent.final - rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited