ExecutorIdentityConverter class final
Provides serialization and dictionary-key support for ExecutorIdentity values.
ExecutorIdentity.none is represented as an empty string; other
identities are represented as @{id}.
- Inheritance
-
- Object
- JsonConverterBase<
ExecutorIdentity> - JsonConverterDictionarySupportBase<
ExecutorIdentity> - ExecutorIdentityConverter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
Object? json) → ExecutorIdentity? -
Deserializes
jsoninto aT, ornullif conversion fails.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String key) → ExecutorIdentity -
Parses a JSON map key back into
T.override -
stringify(
ExecutorIdentity value) → String -
Converts
valueto a string suitable for use as a JSON map key.override -
toJson(
ExecutorIdentity value) → Object? -
Serializes
valueto a JSON-compatible object.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited