GroupChatManager class abstract
A manager that manages the flow of a group chat.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterationCount ↔ int
-
Gets the number of iterations in the group chat so far.
getter/setter pair
- maximumIterationCount ↔ int
-
The maximum number of iterations allowed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Resets the state of the manager for a new group chat session.
-
selectNextAgent(
List< ChatMessage> history, {CancellationToken? cancellationToken}) → Future<AIAgent> - Selects the next agent to participate in the group chat.
-
shouldTerminate(
List< ChatMessage> history, {CancellationToken? cancellationToken}) → Future<bool> - Determines whether the group chat should be terminated.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateHistory(
List< ChatMessage> history, {CancellationToken? cancellationToken}) → Future<Iterable< ChatMessage> > - Filters the chat history before it is passed to the next agent.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited