GroupChatWorkflowBuilder class
Provides a builder for specifying group chat relationships between agents.
Constructors
-
GroupChatWorkflowBuilder(GroupChatManager managerFactory(List<
AIAgent> agents)) - Creates a group chat workflow builder.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
managerFactory
→ GroupChatManager Function(List<
AIAgent> agents) -
Function that creates the GroupChatManager for a workflow instance.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addParticipants(
Iterable< AIAgent> agents) → GroupChatWorkflowBuilder -
Adds the specified
agentsas participants to the group chat workflow. -
build(
) → Workflow - Builds a Workflow composed of agents that operate via group chat.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withDescription(
String description) → GroupChatWorkflowBuilder - Sets the description for the workflow.
-
withName(
String name) → GroupChatWorkflowBuilder - Sets the human-readable name for the workflow.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited