HandoffStartExecutor class
Executor used at the start of a handoff workflow.
- Inheritance
- Implemented types
Constructors
-
HandoffStartExecutor({required AIAgent initialAgent, required Map<
String, List< targets, String? handoffInstructions, bool emitAgentResponseEvents = false, bool? emitAgentResponseUpdateEvents, HandoffToolCallFilteringBehavior toolCallFilteringBehavior = HandoffToolCallFilteringBehavior.handoffOnly, bool returnToPrevious = false})HandoffTarget> > - Creates a HandoffStartExecutor.
Properties
- emitAgentResponseEvents → bool
-
Gets whether aggregated response events should be emitted.
final
- emitAgentResponseUpdateEvents → bool?
-
Gets whether streaming update events should be emitted.
final
- handoffInstructions → String?
-
Gets instructions supplied when handoff tools are available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Gets the executor identifier.
finalinherited
- initialAgent → AIAgent
-
Gets the initial agent.
final
- options → ExecutorOptions
-
Gets options describing runtime behavior for this executor.
finalinherited
- protocol → ProtocolDescriptor
-
Gets the executor protocol descriptor.
no setterinherited
- returnToPrevious → bool
-
Gets whether future turns should return to the previous specialist.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targets
→ Map<
String, List< HandoffTarget> > -
Gets handoff targets by source agent ID.
final
- toolCallFilteringBehavior → HandoffToolCallFilteringBehavior
-
Gets the handoff tool call filtering behavior.
final
Methods
-
canAccept(
Type messageType) → bool -
Gets whether this executor can accept a message of
messageType.inherited -
configureProtocol(
ProtocolBuilder builder) → void -
Configures the message protocol for this executor.
override
-
describeProtocol(
) → ProtocolDescriptor -
Builds the executor protocol descriptor.
inherited
-
handle(
Object? message, WorkflowContext context, {CancellationToken? cancellationToken}) → Future< List< ChatMessage> > -
Handles an inbound message.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → Future< bool> -
Attempts to reset the executor.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- executorId → const String
- Gets the executor identifier.