McpTaskOptions class
Options that control task-augmented MCP tool invocation.
Constructors
- McpTaskOptions({Duration? defaultTimeToLive, bool cancelRemoteTaskOnLocalCancellation = true})
- Creates task invocation options.
Properties
- cancelRemoteTaskOnLocalCancellation → bool
-
Whether local cancellation should best-effort cancel the remote MCP task.
final
- defaultTimeToLive → Duration?
-
Default task time-to-live sent as
task.ttl, when set.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited