MessageMerger class
Merges streams of AgentResponseUpdates grouped by response and message identifiers into coherent AgentResponse objects.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addUpdate(
AgentResponseUpdate update) → void -
Adds
updateto the merge state keyed by its AgentResponseUpdate.responseId. -
computeMerged(
{required String primaryResponseId, String? primaryAgentId, String? primaryAgentName}) → AgentResponse - Merges all accumulated updates into a single AgentResponse.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited