ProtocolBuilder class
Builder used by executors to describe their accepted and produced messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptsAllMessages(
) → ProtocolBuilder - Marks this protocol as accepting every message type.
-
acceptsMessage<
T> () → ProtocolBuilder -
Marks this protocol as accepting messages of type
T. -
acceptsMessageType(
Type type) → ProtocolBuilder -
Marks this protocol as accepting messages of the given runtime
type. -
build(
) → ProtocolDescriptor - Builds an immutable protocol descriptor.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requests<
TRequest, TResponse> (RequestPort< TRequest, TResponse> port) → ProtocolBuilder - Adds a request/response port to the protocol.
-
requestsDescriptor(
RequestPortDescriptor port) → ProtocolBuilder - Adds an existing request port descriptor to the protocol.
-
sendsMessage<
T> () → ProtocolBuilder -
Marks this protocol as producing messages of type
T. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited