RequestPortDescriptor class
Non-generic description for a RequestPort.
- Implemented types
- Available extensions
Constructors
- RequestPortDescriptor(String id, {required Type requestType, required Type responseType, String? description})
-
Creates a request port descriptor.
const
Properties
- description → String?
-
Gets an optional human-readable description for the port.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Gets the port identifier.
final
- requestType → Type
-
Gets the request payload type.
final
- responseType → Type
-
Gets the response payload type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPortInfo(
) → RequestPortInfo -
Available on RequestPortDescriptor, provided by the RequestPortDescriptorRepresentation extension
Returns a RequestPortInfo describing this port. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override