SuperStepEvent class
Base class for SuperStep-scoped events.
- Inheritance
-
- Object
- WorkflowEvent
- SuperStepEvent
- Implementers
Constructors
- SuperStepEvent(int stepNumber, {Object? data})
-
Creates a super-step event.
const
Properties
- data → Object?
-
Gets event payload data, if any.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepNumber → int
-
Gets the zero-based SuperStep index associated with this event.
final
Methods
-
asValue<
T> () → T -
Gets the event payload as
T.inherited -
isType(
Type type) → bool -
Gets whether the event payload has exactly runtime type
type.inherited -
isValue<
T> () → bool -
Gets whether the event payload is a
T.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited