TaskAwareMcpClientAIFunction class
An MCP tool function that must be invoked through task augmentation.
- Inheritance
-
- Object
- McpClientAIFunction
- TaskAwareMcpClientAIFunction
Constructors
- TaskAwareMcpClientAIFunction({required McpClient client, required Tool tool, McpTaskOptions? options})
- Creates a task-aware MCP tool function.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- client → McpClient
-
The MCP client used to invoke the tool.
finalinherited
- description → String?
-
A description of the tool.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStrict → bool?
-
Whether the function requires strict schema adherence.
finalinherited
- name → String
-
The name of the tool.
finalinherited
- options → McpTaskOptions
-
Options used for task-based calls.
final
-
parametersSchema
→ Map<
String, dynamic> ? -
The JSON schema describing the function's input parameters.
finalinherited
-
returnSchema
→ Map<
String, dynamic> ? -
The JSON schema describing the function's return value.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool → Tool
-
The MCP tool declaration.
finalinherited
Methods
-
getService<
T> ({Object? key}) → T? -
Gets a service of the specified type.
inherited
-
invoke(
AIFunctionArguments? arguments, {CancellationToken? cancellationToken}) → Future< Object?> -
Invokes the function with the given
arguments.inherited -
invokeCore(
AIFunctionArguments arguments, {CancellationToken? cancellationToken}) → Future< Object?> -
Core implementation of function invocation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited