The keys used to store provider state in the StateBag.
StateBag
Defaults to a single key equal to the runtime type name.
@override List<String> get stateKeys { return _stateKeys ??= [_sessionState.stateKey]; }